﻿/// <reference path="../Scripts/jspack-vsdoc.js" />

var Diagram = MindFusion.Diagramming.Diagram;
var GlassEffect = MindFusion.Diagramming.GlassEffect;
var Style = MindFusion.Diagramming.Style;

document.addEventListener("DOMContentLoaded", function ()
{
	// create a Diagram component that wraps the "diagram" canvas
    diagram = Diagram.create(document.getElementById("diagram"));

    //styling
    var shapeNodeStyle = new Style();
    shapeNodeStyle.setBrush({ type: 'SolidBrush', color: '#e0e9e9' });
    shapeNodeStyle.setStroke("#7F7F7F");
    shapeNodeStyle.setFontName("Verdana");
    shapeNodeStyle.setFontSize(4);
    shapeNodeStyle.setNodeEffects([new GlassEffect()]);
    diagram.setStyle(shapeNodeStyle);
	
	diagram.setBounds(new MindFusion.Drawing.Rect(0, 0, 500, 500));

    // create a NodeListView component that wraps the "nodeList" canvas
	var nodeList = MindFusion.Diagramming.NodeListView.create(document.getElementById("nodeList"));
	nodeList.setTargetView(document.getElementById("diagram"));
	nodeList.setIconSize(null);
	nodeList.setDefaultNodeSize (null);
	initNodeList(nodeList, diagram);

	// create an Overview component that wraps the "overview" canvas
	var overview = MindFusion.Diagramming.Overview.create(document.getElementById("overview"));
	overview.setDiagram(diagram);

	// create an ZoomControl component that wraps the "zoomer" canvas
	var zoomer = MindFusion.Controls.ZoomControl.create(document.getElementById("zoomer"));
	zoomer.setTarget(diagram);

	// create an Ruler component that wraps the "ruler" div
	var ruler = MindFusion.Diagramming.Ruler.create(document.getElementById("ruler"));
	ruler.setDiagram(diagram);

});

function initNodeList(nodeList, diagram)
{
	// add some nodes to the NodeListView
	var shapes = ["Actor", "RoundRect", "Triangle", "Decision"];
	for (var i = 0; i < shapes.length; ++i)
	{
		var node = new MindFusion.Diagramming.ShapeNode(diagram);
		node.setText(shapes[i]);
		node.setShape(shapes[i]);
        node.setBounds(new MindFusion.Drawing.Rect(0, 0, (i+1)*10, (i+1)*10));
		nodeList.addNode(node, shapes[i]);
	}
}